﻿using System;
using System.Collections.Generic;
using System.Text;

using Autodesk.AutoCAD.Runtime;
using Autodesk.AutoCAD.Customization;
using System.Collections.Specialized;

[assembly: CommandClass(typeof(AutoCAD_PopMenuTest.Main))]
namespace AutoCAD_PopMenuTest
{
    class Main
    {
        [CommandMethod("BMPM")]
        public void BuildMyPopMenu()
        {
            try
            {
                //自定义的组名
                string strMyGroupName = "MyGroup";
                //保存的CUI文件名（从CAD2010开始，后缀改为了cuix）
                //这里可以写文件路径或者仅写文件名
                //如果仅写文件名，则最后保存时将默认保存在此程序集DLL所在目录
                //如果写文件路径，则会按路径进行保存
                string strCuiFileName = "MyMenu.cui";

                //创建一个自定义组（这个组中将包含我们自定义的命令、菜单、工具栏、面板等）
                CustomizationSection myCSection = new CustomizationSection();
                myCSection.MenuGroupName = strMyGroupName;

                //创建自定义命令组
                MacroGroup mg = new MacroGroup("MyMethod", myCSection.MenuGroup);
                MenuMacro mm1 = new MenuMacro(mg, "打开文件", "OF", "");
                MenuMacro mm2 = new MenuMacro(mg, "打开模板", "OM", "");
                MenuMacro mm3 = new MenuMacro(mg, "保存", "SV", "");

                //声明菜单别名
                StringCollection scMyMenuAlias = new StringCollection();  //菜单别名（仅查看CUI源文件时能看到）
                scMyMenuAlias.Add("MyPop1");
                scMyMenuAlias.Add("MyTestPop");

                //菜单项（将显示在项部菜单栏中）
                PopMenu pmParent = new PopMenu("我的菜单", scMyMenuAlias, "我的菜单", myCSection.MenuGroup);

                //子项的菜单（多级）
                //***多级菜单时，子项列表放到一个单独的PopMenu中，然后将此PopMenu放到一个PopMenuRef中
                //***最后将PopMenuRef添加到菜单中
                PopMenu pm1 = new PopMenu("打开", new StringCollection(), "", myCSection.MenuGroup);
                PopMenuRef pmr1 = new PopMenuRef(pm1, pmParent, -1);
                PopMenuItem pmi1 = new PopMenuItem(mm1, "文件", pm1, -1);
                PopMenuItem pmi2 = new PopMenuItem(mm2, "模板", pm1, -1);

                //子项的菜单（单级）
                PopMenuItem pmi3 = new PopMenuItem(mm3, "保存(&S)", pmParent, -1);

                // 最后保存文件
                myCSection.SaveAs(strCuiFileName);
            }
            catch (System.Exception ex)
            {
                throw new System.Exception("自定义CAD菜单失败：" + ex.Message);
            }
        }
    }
}
